cappr.huggingface
========================

.. automodule:: cappr.huggingface
   :members:
   :undoc-members:
   :show-inheritance:



.. toctree::
   :maxdepth: 4

   cappr.huggingface.classify
   cappr.huggingface.classify_no_batch
   cappr.huggingface.classify_no_cache
   cappr.huggingface.classify_no_cache_no_batch
